proto

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	AgentService_Connect_FullMethodName     = "/ax.AgentService/Connect"
	AgentService_HealthCheck_FullMethodName = "/ax.AgentService/HealthCheck"
)
const (
	ConversationService_DeleteConversation_FullMethodName = "/ax.ConversationService/DeleteConversation"
	ConversationService_ForkConversation_FullMethodName   = "/ax.ConversationService/ForkConversation"
)
const (
	ControllerService_Exec_FullMethodName = "/ax.ControllerService/Exec"
)

Variables

var (
	State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "STATE_PENDING",
		2: "STATE_FAILED",
		3: "STATE_COMPLETED",
	}
	State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"STATE_PENDING":     1,
		"STATE_FAILED":      2,
		"STATE_COMPLETED":   3,
	}
)

Enum value maps for State.

var (
	MediaResolution_name = map[int32]string{
		0: "MEDIA_RESOLUTION_UNSPECIFIED",
		1: "LOW",
		2: "MEDIUM",
		3: "HIGH",
		4: "ULTRA_HIGH",
	}
	MediaResolution_value = map[string]int32{
		"MEDIA_RESOLUTION_UNSPECIFIED": 0,
		"LOW":                          1,
		"MEDIUM":                       2,
		"HIGH":                         3,
		"ULTRA_HIGH":                   4,
	}
)

Enum value maps for MediaResolution.

var (
	ImageContent_MimeType_name = map[int32]string{
		0: "TYPE_UNSPECIFIED",
		1: "TYPE_PNG",
		2: "TYPE_JPEG",
		3: "TYPE_WEBP",
		4: "TYPE_HEIC",
		5: "TYPE_HEIF",
		7: "TYPE_GIF",
		8: "TYPE_BMP",
		9: "TYPE_TIFF",
	}
	ImageContent_MimeType_value = map[string]int32{
		"TYPE_UNSPECIFIED": 0,
		"TYPE_PNG":         1,
		"TYPE_JPEG":        2,
		"TYPE_WEBP":        3,
		"TYPE_HEIC":        4,
		"TYPE_HEIF":        5,
		"TYPE_GIF":         7,
		"TYPE_BMP":         8,
		"TYPE_TIFF":        9,
	}
)

Enum value maps for ImageContent_MimeType.

var (
	AudioContent_MimeType_name = map[int32]string{
		0:  "TYPE_UNSPECIFIED",
		1:  "TYPE_WAV",
		2:  "TYPE_MP3",
		3:  "TYPE_AIFF",
		4:  "TYPE_AAC",
		5:  "TYPE_OGG",
		6:  "TYPE_FLAC",
		7:  "TYPE_MPEG",
		8:  "TYPE_M4A",
		9:  "TYPE_L16",
		10: "TYPE_S16LE",
		11: "TYPE_OPUS",
		12: "TYPE_ALAW",
		13: "TYPE_MULAW",
	}
	AudioContent_MimeType_value = map[string]int32{
		"TYPE_UNSPECIFIED": 0,
		"TYPE_WAV":         1,
		"TYPE_MP3":         2,
		"TYPE_AIFF":        3,
		"TYPE_AAC":         4,
		"TYPE_OGG":         5,
		"TYPE_FLAC":        6,
		"TYPE_MPEG":        7,
		"TYPE_M4A":         8,
		"TYPE_L16":         9,
		"TYPE_S16LE":       10,
		"TYPE_OPUS":        11,
		"TYPE_ALAW":        12,
		"TYPE_MULAW":       13,
	}
)

Enum value maps for AudioContent_MimeType.

var (
	DocumentContent_MimeType_name = map[int32]string{
		0: "TYPE_UNSPECIFIED",
		1: "TYPE_PDF",
		2: "TYPE_JSON",
		3: "TYPE_PYTHON",
	}
	DocumentContent_MimeType_value = map[string]int32{
		"TYPE_UNSPECIFIED": 0,
		"TYPE_PDF":         1,
		"TYPE_JSON":        2,
		"TYPE_PYTHON":      3,
	}
)

Enum value maps for DocumentContent_MimeType.

var (
	VideoContent_MimeType_name = map[int32]string{
		0: "TYPE_UNSPECIFIED",
		1: "TYPE_MP4",
		2: "TYPE_MPEG",
		3: "TYPE_MPG",
		4: "TYPE_MOV",
		5: "TYPE_AVI",
		6: "TYPE_X_FLV",
		7: "TYPE_WEBM",
		8: "TYPE_WMV",
		9: "TYPE_3GPP",
	}
	VideoContent_MimeType_value = map[string]int32{
		"TYPE_UNSPECIFIED": 0,
		"TYPE_MP4":         1,
		"TYPE_MPEG":        2,
		"TYPE_MPG":         3,
		"TYPE_MOV":         4,
		"TYPE_AVI":         5,
		"TYPE_X_FLV":       6,
		"TYPE_WEBM":        7,
		"TYPE_WMV":         8,
		"TYPE_3GPP":        9,
	}
)

Enum value maps for VideoContent_MimeType.

var AgentService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ax.AgentService",
	HandlerType: (*AgentServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "HealthCheck",
			Handler:    _AgentService_HealthCheck_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "Connect",
			Handler:       _AgentService_Connect_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
	},
	Metadata: "proto/ax.proto",
}

AgentService_ServiceDesc is the grpc.ServiceDesc for AgentService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ControllerService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ax.ControllerService",
	HandlerType: (*ControllerServiceServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "Exec",
			Handler:       _ControllerService_Exec_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "proto/ax.proto",
}

ControllerService_ServiceDesc is the grpc.ServiceDesc for ControllerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ConversationService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "ax.ConversationService",
	HandlerType: (*ConversationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "DeleteConversation",
			Handler:    _ConversationService_DeleteConversation_Handler,
		},
		{
			MethodName: "ForkConversation",
			Handler:    _ConversationService_ForkConversation_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/ax.proto",
}

ConversationService_ServiceDesc is the grpc.ServiceDesc for ConversationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_proto_ax_proto protoreflect.FileDescriptor
var File_proto_content_proto protoreflect.FileDescriptor

Functions

func RegisterAgentServiceServer

func RegisterAgentServiceServer(s grpc.ServiceRegistrar, srv AgentServiceServer)

func RegisterControllerServiceServer

func RegisterControllerServiceServer(s grpc.ServiceRegistrar, srv ControllerServiceServer)

func RegisterConversationServiceServer

func RegisterConversationServiceServer(s grpc.ServiceRegistrar, srv ConversationServiceServer)

Types

type AgentEnd

type AgentEnd struct {
	// contains filtered or unexported fields
}

func (*AgentEnd) Descriptor deprecated

func (*AgentEnd) Descriptor() ([]byte, []int)

Deprecated: Use AgentEnd.ProtoReflect.Descriptor instead.

func (*AgentEnd) ProtoMessage

func (*AgentEnd) ProtoMessage()

func (*AgentEnd) ProtoReflect

func (x *AgentEnd) ProtoReflect() protoreflect.Message

func (*AgentEnd) Reset

func (x *AgentEnd) Reset()

func (*AgentEnd) String

func (x *AgentEnd) String() string

type AgentMessage

type AgentMessage struct {
	ConversationId string `protobuf:"bytes,1,opt,name=conversation_id,json=conversationId,proto3" json:"conversation_id,omitempty"`
	ExecId         string `protobuf:"bytes,2,opt,name=exec_id,json=execId,proto3" json:"exec_id,omitempty"`
	// Types that are valid to be assigned to Type:
	//
	//	*AgentMessage_Start
	//	*AgentMessage_Outputs
	//	*AgentMessage_End
	Type isAgentMessage_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

func (*AgentMessage) Descriptor deprecated

func (*AgentMessage) Descriptor() ([]byte, []int)

Deprecated: Use AgentMessage.ProtoReflect.Descriptor instead.

func (*AgentMessage) GetConversationId

func (x *AgentMessage) GetConversationId() string

func (*AgentMessage) GetEnd

func (x *AgentMessage) GetEnd() *AgentEnd

func (*AgentMessage) GetExecId

func (x *AgentMessage) GetExecId() string

func (*AgentMessage) GetOutputs

func (x *AgentMessage) GetOutputs() *AgentOutputs

func (*AgentMessage) GetStart

func (x *AgentMessage) GetStart() *AgentStart

func (*AgentMessage) GetType

func (x *AgentMessage) GetType() isAgentMessage_Type

func (*AgentMessage) ProtoMessage

func (*AgentMessage) ProtoMessage()

func (*AgentMessage) ProtoReflect

func (x *AgentMessage) ProtoReflect() protoreflect.Message

func (*AgentMessage) Reset

func (x *AgentMessage) Reset()

func (*AgentMessage) String

func (x *AgentMessage) String() string

type AgentMessage_End

type AgentMessage_End struct {
	End *AgentEnd `protobuf:"bytes,5,opt,name=end,proto3,oneof"`
}

type AgentMessage_Outputs

type AgentMessage_Outputs struct {
	Outputs *AgentOutputs `protobuf:"bytes,4,opt,name=outputs,proto3,oneof"`
}

type AgentMessage_Start

type AgentMessage_Start struct {
	Start *AgentStart `protobuf:"bytes,3,opt,name=start,proto3,oneof"`
}

type AgentOutputs

type AgentOutputs struct {
	Messages []*Message `protobuf:"bytes,1,rep,name=messages,proto3" json:"messages,omitempty"`
	// contains filtered or unexported fields
}

func (*AgentOutputs) Descriptor deprecated

func (*AgentOutputs) Descriptor() ([]byte, []int)

Deprecated: Use AgentOutputs.ProtoReflect.Descriptor instead.

func (*AgentOutputs) GetMessages

func (x *AgentOutputs) GetMessages() []*Message

func (*AgentOutputs) ProtoMessage

func (*AgentOutputs) ProtoMessage()

func (*AgentOutputs) ProtoReflect

func (x *AgentOutputs) ProtoReflect() protoreflect.Message

func (*AgentOutputs) Reset

func (x *AgentOutputs) Reset()

func (*AgentOutputs) String

func (x *AgentOutputs) String() string

type AgentServiceClient

type AgentServiceClient interface {
	// Connect is used by agents to connect to the controller.
	Connect(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[AgentMessage, AgentMessage], error)
	// HealthCheck checks if the agent is healthy and responsive
	HealthCheck(ctx context.Context, in *HealthCheckRequest, opts ...grpc.CallOption) (*HealthCheckResponse, error)
}

AgentServiceClient is the client API for AgentService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

AgentService defines the gRPC service for agent communication. This protocol enables a bidirectional communication between the controller and the agent. Agents can start new agentic calls via the controller within the same execution boundary by using the channel.

WARNING: There will be significant changes to this protocol as we are solidifying resumption on the wire.

type AgentServiceServer

type AgentServiceServer interface {
	// Connect is used by agents to connect to the controller.
	Connect(grpc.BidiStreamingServer[AgentMessage, AgentMessage]) error
	// HealthCheck checks if the agent is healthy and responsive
	HealthCheck(context.Context, *HealthCheckRequest) (*HealthCheckResponse, error)
	// contains filtered or unexported methods
}

AgentServiceServer is the server API for AgentService service. All implementations must embed UnimplementedAgentServiceServer for forward compatibility.

AgentService defines the gRPC service for agent communication. This protocol enables a bidirectional communication between the controller and the agent. Agents can start new agentic calls via the controller within the same execution boundary by using the channel.

WARNING: There will be significant changes to this protocol as we are solidifying resumption on the wire.

type AgentService_ConnectClient

type AgentService_ConnectClient = grpc.BidiStreamingClient[AgentMessage, AgentMessage]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AgentService_ConnectServer

type AgentService_ConnectServer = grpc.BidiStreamingServer[AgentMessage, AgentMessage]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type AgentStart

type AgentStart struct {
	AgentId     string     `protobuf:"bytes,1,opt,name=agent_id,json=agentId,proto3" json:"agent_id,omitempty"`
	AgentConfig []byte     `protobuf:"bytes,2,opt,name=agent_config,json=agentConfig,proto3" json:"agent_config,omitempty"`
	Messages    []*Message `protobuf:"bytes,3,rep,name=messages,proto3" json:"messages,omitempty"`
	// contains filtered or unexported fields
}

func (*AgentStart) Descriptor deprecated

func (*AgentStart) Descriptor() ([]byte, []int)

Deprecated: Use AgentStart.ProtoReflect.Descriptor instead.

func (*AgentStart) GetAgentConfig

func (x *AgentStart) GetAgentConfig() []byte

func (*AgentStart) GetAgentId

func (x *AgentStart) GetAgentId() string

func (*AgentStart) GetMessages

func (x *AgentStart) GetMessages() []*Message

func (*AgentStart) ProtoMessage

func (*AgentStart) ProtoMessage()

func (*AgentStart) ProtoReflect

func (x *AgentStart) ProtoReflect() protoreflect.Message

func (*AgentStart) Reset

func (x *AgentStart) Reset()

func (*AgentStart) String

func (x *AgentStart) String() string

type ApprovalDecision

type ApprovalDecision struct {
	Approved bool `protobuf:"varint,1,opt,name=approved,proto3" json:"approved,omitempty"`
	// contains filtered or unexported fields
}

func (*ApprovalDecision) Descriptor deprecated

func (*ApprovalDecision) Descriptor() ([]byte, []int)

Deprecated: Use ApprovalDecision.ProtoReflect.Descriptor instead.

func (*ApprovalDecision) GetApproved

func (x *ApprovalDecision) GetApproved() bool

func (*ApprovalDecision) ProtoMessage

func (*ApprovalDecision) ProtoMessage()

func (*ApprovalDecision) ProtoReflect

func (x *ApprovalDecision) ProtoReflect() protoreflect.Message

func (*ApprovalDecision) Reset

func (x *ApprovalDecision) Reset()

func (*ApprovalDecision) String

func (x *ApprovalDecision) String() string

type AudioContent

type AudioContent struct {
	MimeType AudioContent_MimeType `protobuf:"varint,1,opt,name=mime_type,json=mimeType,proto3,enum=ax.AudioContent_MimeType" json:"mime_type,omitempty"`
	// Types that are valid to be assigned to DataOrUri:
	//
	//	*AudioContent_Data
	//	*AudioContent_Uri
	DataOrUri  isAudioContent_DataOrUri `protobuf_oneof:"data_or_uri"`
	Channels   int32                    `protobuf:"varint,7,opt,name=channels,proto3" json:"channels,omitempty"`
	SampleRate int32                    `protobuf:"varint,8,opt,name=sample_rate,json=sampleRate,proto3" json:"sample_rate,omitempty"`
	// contains filtered or unexported fields
}

An audio content block.

func (*AudioContent) Descriptor deprecated

func (*AudioContent) Descriptor() ([]byte, []int)

Deprecated: Use AudioContent.ProtoReflect.Descriptor instead.

func (*AudioContent) GetChannels

func (x *AudioContent) GetChannels() int32

func (*AudioContent) GetData

func (x *AudioContent) GetData() []byte

func (*AudioContent) GetDataOrUri

func (x *AudioContent) GetDataOrUri() isAudioContent_DataOrUri

func (*AudioContent) GetMimeType

func (x *AudioContent) GetMimeType() AudioContent_MimeType

func (*AudioContent) GetSampleRate

func (x *AudioContent) GetSampleRate() int32

func (*AudioContent) GetUri

func (x *AudioContent) GetUri() string

func (*AudioContent) ProtoMessage

func (*AudioContent) ProtoMessage()

func (*AudioContent) ProtoReflect

func (x *AudioContent) ProtoReflect() protoreflect.Message

func (*AudioContent) Reset

func (x *AudioContent) Reset()

func (*AudioContent) String

func (x *AudioContent) String() string

type AudioContent_Data

type AudioContent_Data struct {
	Data []byte `protobuf:"bytes,2,opt,name=data,proto3,oneof"`
}

type AudioContent_MimeType

type AudioContent_MimeType int32
const (
	AudioContent_TYPE_UNSPECIFIED AudioContent_MimeType = 0
	AudioContent_TYPE_WAV         AudioContent_MimeType = 1  // audio/wav
	AudioContent_TYPE_MP3         AudioContent_MimeType = 2  // audio/mp3
	AudioContent_TYPE_AIFF        AudioContent_MimeType = 3  // audio/aiff
	AudioContent_TYPE_AAC         AudioContent_MimeType = 4  // audio/aac
	AudioContent_TYPE_OGG         AudioContent_MimeType = 5  // audio/ogg
	AudioContent_TYPE_FLAC        AudioContent_MimeType = 6  // audio/flac
	AudioContent_TYPE_MPEG        AudioContent_MimeType = 7  // audio/mpeg
	AudioContent_TYPE_M4A         AudioContent_MimeType = 8  // audio/m4a
	AudioContent_TYPE_L16         AudioContent_MimeType = 9  // audio/l16
	AudioContent_TYPE_S16LE       AudioContent_MimeType = 10 // audio/s16le
	AudioContent_TYPE_OPUS        AudioContent_MimeType = 11 // audio/opus
	AudioContent_TYPE_ALAW        AudioContent_MimeType = 12 // audio/alaw
	AudioContent_TYPE_MULAW       AudioContent_MimeType = 13 // audio/mulaw
)

func (AudioContent_MimeType) Descriptor

func (AudioContent_MimeType) Enum

func (AudioContent_MimeType) EnumDescriptor deprecated

func (AudioContent_MimeType) EnumDescriptor() ([]byte, []int)

Deprecated: Use AudioContent_MimeType.Descriptor instead.

func (AudioContent_MimeType) Number

func (AudioContent_MimeType) String

func (x AudioContent_MimeType) String() string

func (AudioContent_MimeType) Type

type AudioContent_Uri

type AudioContent_Uri struct {
	Uri string `protobuf:"bytes,5,opt,name=uri,proto3,oneof"`
}

type ConfirmationContent

type ConfirmationContent struct {
	Id       string `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	Question string `protobuf:"bytes,4,opt,name=question,proto3" json:"question,omitempty"`
	// Types that are valid to be assigned to Decision:
	//
	//	*ConfirmationContent_Approval
	//	*ConfirmationContent_Decline
	Decision isConfirmationContent_Decision `protobuf_oneof:"decision"`
	// contains filtered or unexported fields
}

func (*ConfirmationContent) Descriptor deprecated

func (*ConfirmationContent) Descriptor() ([]byte, []int)

Deprecated: Use ConfirmationContent.ProtoReflect.Descriptor instead.

func (*ConfirmationContent) GetApproval

func (x *ConfirmationContent) GetApproval() *ApprovalDecision

func (*ConfirmationContent) GetDecision

func (x *ConfirmationContent) GetDecision() isConfirmationContent_Decision

func (*ConfirmationContent) GetDecline

func (x *ConfirmationContent) GetDecline() *DeclineDecision

func (*ConfirmationContent) GetId

func (x *ConfirmationContent) GetId() string

func (*ConfirmationContent) GetQuestion

func (x *ConfirmationContent) GetQuestion() string

func (*ConfirmationContent) ProtoMessage

func (*ConfirmationContent) ProtoMessage()

func (*ConfirmationContent) ProtoReflect

func (x *ConfirmationContent) ProtoReflect() protoreflect.Message

func (*ConfirmationContent) Reset

func (x *ConfirmationContent) Reset()

func (*ConfirmationContent) String

func (x *ConfirmationContent) String() string

type ConfirmationContent_Approval

type ConfirmationContent_Approval struct {
	Approval *ApprovalDecision `protobuf:"bytes,5,opt,name=approval,proto3,oneof"`
}

type ConfirmationContent_Decline

type ConfirmationContent_Decline struct {
	Decline *DeclineDecision `protobuf:"bytes,6,opt,name=decline,proto3,oneof"`
}

type Content

type Content struct {

	// Types that are valid to be assigned to Type:
	//
	//	*Content_Thought
	//	*Content_Text
	//	*Content_Image
	//	*Content_Audio
	//	*Content_Document
	//	*Content_Video
	//	*Content_Confirmation
	//	*Content_ToolCall
	//	*Content_ToolResult
	Type isContent_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

Content represents a content input or output.

func (*Content) Descriptor deprecated

func (*Content) Descriptor() ([]byte, []int)

Deprecated: Use Content.ProtoReflect.Descriptor instead.

func (*Content) GetAudio

func (x *Content) GetAudio() *AudioContent

func (*Content) GetConfirmation

func (x *Content) GetConfirmation() *ConfirmationContent

func (*Content) GetDocument

func (x *Content) GetDocument() *DocumentContent

func (*Content) GetImage

func (x *Content) GetImage() *ImageContent

func (*Content) GetText

func (x *Content) GetText() *TextContent

func (*Content) GetThought

func (x *Content) GetThought() *ThoughtContent

func (*Content) GetToolCall

func (x *Content) GetToolCall() *ToolCallContent

func (*Content) GetToolResult

func (x *Content) GetToolResult() *ToolResultContent

func (*Content) GetType

func (x *Content) GetType() isContent_Type

func (*Content) GetVideo

func (x *Content) GetVideo() *VideoContent

func (*Content) ProtoMessage

func (*Content) ProtoMessage()

func (*Content) ProtoReflect

func (x *Content) ProtoReflect() protoreflect.Message

func (*Content) Reset

func (x *Content) Reset()

func (*Content) String

func (x *Content) String() string

type Content_Audio

type Content_Audio struct {
	Audio *AudioContent `protobuf:"bytes,12,opt,name=audio,proto3,oneof"`
}

type Content_Confirmation

type Content_Confirmation struct {
	Confirmation *ConfirmationContent `protobuf:"bytes,26,opt,name=confirmation,proto3,oneof"` // TODO(jbd): Remove out of the Content.
}

type Content_Document

type Content_Document struct {
	Document *DocumentContent `protobuf:"bytes,13,opt,name=document,proto3,oneof"`
}

type Content_Image

type Content_Image struct {
	Image *ImageContent `protobuf:"bytes,11,opt,name=image,proto3,oneof"`
}

type Content_Text

type Content_Text struct {
	Text *TextContent `protobuf:"bytes,10,opt,name=text,proto3,oneof"`
}

type Content_Thought

type Content_Thought struct {
	Thought *ThoughtContent `protobuf:"bytes,5,opt,name=thought,proto3,oneof"`
}

type Content_ToolCall

type Content_ToolCall struct {
	ToolCall *ToolCallContent `protobuf:"bytes,24,opt,name=tool_call,json=toolCall,proto3,oneof"`
}

type Content_ToolResult

type Content_ToolResult struct {
	ToolResult *ToolResultContent `protobuf:"bytes,25,opt,name=tool_result,json=toolResult,proto3,oneof"`
}

type Content_Video

type Content_Video struct {
	Video *VideoContent `protobuf:"bytes,14,opt,name=video,proto3,oneof"`
}

type ControllerServiceClient

type ControllerServiceClient interface {
	// Exec executes an agentic task or resumes an existing one with streaming responses
	// If the conversation_id already exists, it will be resumed.
	Exec(ctx context.Context, in *ExecRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[ExecResponse], error)
}

ControllerServiceClient is the client API for ControllerService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ControllerServiceServer

type ControllerServiceServer interface {
	// Exec executes an agentic task or resumes an existing one with streaming responses
	// If the conversation_id already exists, it will be resumed.
	Exec(*ExecRequest, grpc.ServerStreamingServer[ExecResponse]) error
	// contains filtered or unexported methods
}

ControllerServiceServer is the server API for ControllerService service. All implementations must embed UnimplementedControllerServiceServer for forward compatibility.

type ControllerService_ExecClient

type ControllerService_ExecClient = grpc.ServerStreamingClient[ExecResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type ControllerService_ExecServer

type ControllerService_ExecServer = grpc.ServerStreamingServer[ExecResponse]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type ConversationEvent

type ConversationEvent struct {
	ConversationId string     `protobuf:"bytes,1,opt,name=conversation_id,json=conversationId,proto3" json:"conversation_id,omitempty"`
	Seq            int32      `protobuf:"varint,2,opt,name=seq,proto3" json:"seq,omitempty"`
	ExecId         string     `protobuf:"bytes,3,opt,name=exec_id,json=execId,proto3" json:"exec_id,omitempty"`
	Messages       []*Message `protobuf:"bytes,4,rep,name=messages,proto3" json:"messages,omitempty"`
	State          State      `protobuf:"varint,5,opt,name=state,proto3,enum=ax.State" json:"state,omitempty"`
	// contains filtered or unexported fields
}

A conversation is the historical session that consist of a number of execution. A conversation cannot be continued before the last execution is completed or failed.

func (*ConversationEvent) Descriptor deprecated

func (*ConversationEvent) Descriptor() ([]byte, []int)

Deprecated: Use ConversationEvent.ProtoReflect.Descriptor instead.

func (*ConversationEvent) GetConversationId

func (x *ConversationEvent) GetConversationId() string

func (*ConversationEvent) GetExecId

func (x *ConversationEvent) GetExecId() string

func (*ConversationEvent) GetMessages

func (x *ConversationEvent) GetMessages() []*Message

func (*ConversationEvent) GetSeq

func (x *ConversationEvent) GetSeq() int32

func (*ConversationEvent) GetState

func (x *ConversationEvent) GetState() State

func (*ConversationEvent) ProtoMessage

func (*ConversationEvent) ProtoMessage()

func (*ConversationEvent) ProtoReflect

func (x *ConversationEvent) ProtoReflect() protoreflect.Message

func (*ConversationEvent) Reset

func (x *ConversationEvent) Reset()

func (*ConversationEvent) String

func (x *ConversationEvent) String() string

type ConversationServiceClient

type ConversationServiceClient interface {
	// Deletes conversational events and all event log resources
	// for its children executions.
	DeleteConversation(ctx context.Context, in *DeleteConversationRequest, opts ...grpc.CallOption) (*DeleteConversationResponse, error)
	// Fork forks an event log from a specific conversation.
	ForkConversation(ctx context.Context, in *ForkConversationRequest, opts ...grpc.CallOption) (*ForkConversationResponse, error)
}

ConversationServiceClient is the client API for ConversationService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ConversationServiceServer

type ConversationServiceServer interface {
	// Deletes conversational events and all event log resources
	// for its children executions.
	DeleteConversation(context.Context, *DeleteConversationRequest) (*DeleteConversationResponse, error)
	// Fork forks an event log from a specific conversation.
	ForkConversation(context.Context, *ForkConversationRequest) (*ForkConversationResponse, error)
	// contains filtered or unexported methods
}

ConversationServiceServer is the server API for ConversationService service. All implementations must embed UnimplementedConversationServiceServer for forward compatibility.

type DeclineDecision

type DeclineDecision struct {
	Declined bool `protobuf:"varint,1,opt,name=declined,proto3" json:"declined,omitempty"`
	// contains filtered or unexported fields
}

func (*DeclineDecision) Descriptor deprecated

func (*DeclineDecision) Descriptor() ([]byte, []int)

Deprecated: Use DeclineDecision.ProtoReflect.Descriptor instead.

func (*DeclineDecision) GetDeclined

func (x *DeclineDecision) GetDeclined() bool

func (*DeclineDecision) ProtoMessage

func (*DeclineDecision) ProtoMessage()

func (*DeclineDecision) ProtoReflect

func (x *DeclineDecision) ProtoReflect() protoreflect.Message

func (*DeclineDecision) Reset

func (x *DeclineDecision) Reset()

func (*DeclineDecision) String

func (x *DeclineDecision) String() string

type DeleteConversationRequest

type DeleteConversationRequest struct {
	ConversationId string `protobuf:"bytes,1,opt,name=conversation_id,json=conversationId,proto3" json:"conversation_id,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteConversationRequest) Descriptor deprecated

func (*DeleteConversationRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteConversationRequest.ProtoReflect.Descriptor instead.

func (*DeleteConversationRequest) GetConversationId

func (x *DeleteConversationRequest) GetConversationId() string

func (*DeleteConversationRequest) ProtoMessage

func (*DeleteConversationRequest) ProtoMessage()

func (*DeleteConversationRequest) ProtoReflect

func (*DeleteConversationRequest) Reset

func (x *DeleteConversationRequest) Reset()

func (*DeleteConversationRequest) String

func (x *DeleteConversationRequest) String() string

type DeleteConversationResponse

type DeleteConversationResponse struct {
	// contains filtered or unexported fields
}

func (*DeleteConversationResponse) Descriptor deprecated

func (*DeleteConversationResponse) Descriptor() ([]byte, []int)

Deprecated: Use DeleteConversationResponse.ProtoReflect.Descriptor instead.

func (*DeleteConversationResponse) ProtoMessage

func (*DeleteConversationResponse) ProtoMessage()

func (*DeleteConversationResponse) ProtoReflect

func (*DeleteConversationResponse) Reset

func (x *DeleteConversationResponse) Reset()

func (*DeleteConversationResponse) String

func (x *DeleteConversationResponse) String() string

type DocumentContent

type DocumentContent struct {
	MimeType DocumentContent_MimeType `protobuf:"varint,1,opt,name=mime_type,json=mimeType,proto3,enum=ax.DocumentContent_MimeType" json:"mime_type,omitempty"`
	// Types that are valid to be assigned to DataOrUri:
	//
	//	*DocumentContent_Data
	//	*DocumentContent_Uri
	DataOrUri isDocumentContent_DataOrUri `protobuf_oneof:"data_or_uri"`
	// contains filtered or unexported fields
}

A document content block.

func (*DocumentContent) Descriptor deprecated

func (*DocumentContent) Descriptor() ([]byte, []int)

Deprecated: Use DocumentContent.ProtoReflect.Descriptor instead.

func (*DocumentContent) GetData

func (x *DocumentContent) GetData() []byte

func (*DocumentContent) GetDataOrUri

func (x *DocumentContent) GetDataOrUri() isDocumentContent_DataOrUri

func (*DocumentContent) GetMimeType

func (x *DocumentContent) GetMimeType() DocumentContent_MimeType

func (*DocumentContent) GetUri

func (x *DocumentContent) GetUri() string

func (*DocumentContent) ProtoMessage

func (*DocumentContent) ProtoMessage()

func (*DocumentContent) ProtoReflect

func (x *DocumentContent) ProtoReflect() protoreflect.Message

func (*DocumentContent) Reset

func (x *DocumentContent) Reset()

func (*DocumentContent) String

func (x *DocumentContent) String() string

type DocumentContent_Data

type DocumentContent_Data struct {
	Data []byte `protobuf:"bytes,2,opt,name=data,proto3,oneof"`
}

type DocumentContent_MimeType

type DocumentContent_MimeType int32
const (
	DocumentContent_TYPE_UNSPECIFIED DocumentContent_MimeType = 0
	DocumentContent_TYPE_PDF         DocumentContent_MimeType = 1 // application/pdf
	DocumentContent_TYPE_JSON        DocumentContent_MimeType = 2 // application/json
	DocumentContent_TYPE_PYTHON      DocumentContent_MimeType = 3 // text/x-python
)

func (DocumentContent_MimeType) Descriptor

func (DocumentContent_MimeType) Enum

func (DocumentContent_MimeType) EnumDescriptor deprecated

func (DocumentContent_MimeType) EnumDescriptor() ([]byte, []int)

Deprecated: Use DocumentContent_MimeType.Descriptor instead.

func (DocumentContent_MimeType) Number

func (DocumentContent_MimeType) String

func (x DocumentContent_MimeType) String() string

func (DocumentContent_MimeType) Type

type DocumentContent_Uri

type DocumentContent_Uri struct {
	Uri string `protobuf:"bytes,5,opt,name=uri,proto3,oneof"`
}

type ExecRequest

type ExecRequest struct {
	ConversationId string     `protobuf:"bytes,1,opt,name=conversation_id,json=conversationId,proto3" json:"conversation_id,omitempty"` // Unique conversation identifier
	Inputs         []*Message `protobuf:"bytes,2,rep,name=inputs,proto3" json:"inputs,omitempty"`                                       // New inputs
	LastSeq        int32      `protobuf:"varint,3,opt,name=last_seq,json=lastSeq,proto3" json:"last_seq,omitempty"`                     // Last sequence number seen by the client
	AgentId        string     `protobuf:"bytes,4,opt,name=agent_id,json=agentId,proto3" json:"agent_id,omitempty"`                      // Agent ID, if empty planner is used
	AgentConfig    []byte     `protobuf:"bytes,5,opt,name=agent_config,json=agentConfig,proto3" json:"agent_config,omitempty"`          // Agent configuration if any
	// contains filtered or unexported fields
}

ExecRequest for executing.

func (*ExecRequest) Descriptor deprecated

func (*ExecRequest) Descriptor() ([]byte, []int)

Deprecated: Use ExecRequest.ProtoReflect.Descriptor instead.

func (*ExecRequest) GetAgentConfig

func (x *ExecRequest) GetAgentConfig() []byte

func (*ExecRequest) GetAgentId

func (x *ExecRequest) GetAgentId() string

func (*ExecRequest) GetConversationId

func (x *ExecRequest) GetConversationId() string

func (*ExecRequest) GetInputs

func (x *ExecRequest) GetInputs() []*Message

func (*ExecRequest) GetLastSeq

func (x *ExecRequest) GetLastSeq() int32

func (*ExecRequest) ProtoMessage

func (*ExecRequest) ProtoMessage()

func (*ExecRequest) ProtoReflect

func (x *ExecRequest) ProtoReflect() protoreflect.Message

func (*ExecRequest) Reset

func (x *ExecRequest) Reset()

func (*ExecRequest) String

func (x *ExecRequest) String() string

type ExecResponse

type ExecResponse struct {
	Outputs []*Message `protobuf:"bytes,1,rep,name=outputs,proto3" json:"outputs,omitempty"` // Output content
	Seq     int32      `protobuf:"varint,2,opt,name=seq,proto3" json:"seq,omitempty"`        // Seq of the outputs
	// contains filtered or unexported fields
}

ExecResponse contains the result of an execution.

func (*ExecResponse) Descriptor deprecated

func (*ExecResponse) Descriptor() ([]byte, []int)

Deprecated: Use ExecResponse.ProtoReflect.Descriptor instead.

func (*ExecResponse) GetOutputs

func (x *ExecResponse) GetOutputs() []*Message

func (*ExecResponse) GetSeq

func (x *ExecResponse) GetSeq() int32

func (*ExecResponse) ProtoMessage

func (*ExecResponse) ProtoMessage()

func (*ExecResponse) ProtoReflect

func (x *ExecResponse) ProtoReflect() protoreflect.Message

func (*ExecResponse) Reset

func (x *ExecResponse) Reset()

func (*ExecResponse) String

func (x *ExecResponse) String() string

type ExecutionEvent

type ExecutionEvent struct {
	ExecId      string                 `protobuf:"bytes,1,opt,name=exec_id,json=execId,proto3" json:"exec_id,omitempty"`
	AgentId     string                 `protobuf:"bytes,2,opt,name=agent_id,json=agentId,proto3" json:"agent_id,omitempty"`
	AgentConfig []byte                 `protobuf:"bytes,3,opt,name=agent_config,json=agentConfig,proto3" json:"agent_config,omitempty"`
	Inputs      []*Message             `protobuf:"bytes,4,rep,name=inputs,proto3" json:"inputs,omitempty"`
	Outputs     []*Message             `protobuf:"bytes,5,rep,name=outputs,proto3" json:"outputs,omitempty"`
	State       State                  `protobuf:"varint,6,opt,name=state,proto3,enum=ax.State" json:"state,omitempty"`
	Timestamp   *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// contains filtered or unexported fields
}

ExecutionEvent is the entry in the event log. ExecutionEvents are used to record the actions taken place in the executor. The executor can replay the events for resumability.

func (*ExecutionEvent) Descriptor deprecated

func (*ExecutionEvent) Descriptor() ([]byte, []int)

Deprecated: Use ExecutionEvent.ProtoReflect.Descriptor instead.

func (*ExecutionEvent) GetAgentConfig

func (x *ExecutionEvent) GetAgentConfig() []byte

func (*ExecutionEvent) GetAgentId

func (x *ExecutionEvent) GetAgentId() string

func (*ExecutionEvent) GetExecId

func (x *ExecutionEvent) GetExecId() string

func (*ExecutionEvent) GetInputs

func (x *ExecutionEvent) GetInputs() []*Message

func (*ExecutionEvent) GetOutputs

func (x *ExecutionEvent) GetOutputs() []*Message

func (*ExecutionEvent) GetState

func (x *ExecutionEvent) GetState() State

func (*ExecutionEvent) GetTimestamp

func (x *ExecutionEvent) GetTimestamp() *timestamppb.Timestamp

func (*ExecutionEvent) ProtoMessage

func (*ExecutionEvent) ProtoMessage()

func (*ExecutionEvent) ProtoReflect

func (x *ExecutionEvent) ProtoReflect() protoreflect.Message

func (*ExecutionEvent) Reset

func (x *ExecutionEvent) Reset()

func (*ExecutionEvent) String

func (x *ExecutionEvent) String() string

type ForkConversationRequest

type ForkConversationRequest struct {

	// Required: The source conversation ID to fork from.
	SrcConversationId string `protobuf:"bytes,1,opt,name=src_conversation_id,json=srcConversationId,proto3" json:"src_conversation_id,omitempty"`
	// Optional: The sequence number to fork from.
	// Defaults to the latest sequence if not set or set to 0.
	SrcSeq int32 `protobuf:"varint,2,opt,name=src_seq,json=srcSeq,proto3" json:"src_seq,omitempty"` // TODO(jbd): Replace this with snapshot_id.
	// Optional: The destination conversation ID.
	// Generates a new UUID if not provided.
	DestConversationId string `protobuf:"bytes,3,opt,name=dest_conversation_id,json=destConversationId,proto3" json:"dest_conversation_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ForkConversationRequest) Descriptor deprecated

func (*ForkConversationRequest) Descriptor() ([]byte, []int)

Deprecated: Use ForkConversationRequest.ProtoReflect.Descriptor instead.

func (*ForkConversationRequest) GetDestConversationId

func (x *ForkConversationRequest) GetDestConversationId() string

func (*ForkConversationRequest) GetSrcConversationId

func (x *ForkConversationRequest) GetSrcConversationId() string

func (*ForkConversationRequest) GetSrcSeq

func (x *ForkConversationRequest) GetSrcSeq() int32

func (*ForkConversationRequest) ProtoMessage

func (*ForkConversationRequest) ProtoMessage()

func (*ForkConversationRequest) ProtoReflect

func (x *ForkConversationRequest) ProtoReflect() protoreflect.Message

func (*ForkConversationRequest) Reset

func (x *ForkConversationRequest) Reset()

func (*ForkConversationRequest) String

func (x *ForkConversationRequest) String() string

type ForkConversationResponse

type ForkConversationResponse struct {
	ConversationId string `protobuf:"bytes,1,opt,name=conversation_id,json=conversationId,proto3" json:"conversation_id,omitempty"` // The ID of the new conversation
	// contains filtered or unexported fields
}

func (*ForkConversationResponse) Descriptor deprecated

func (*ForkConversationResponse) Descriptor() ([]byte, []int)

Deprecated: Use ForkConversationResponse.ProtoReflect.Descriptor instead.

func (*ForkConversationResponse) GetConversationId

func (x *ForkConversationResponse) GetConversationId() string

func (*ForkConversationResponse) ProtoMessage

func (*ForkConversationResponse) ProtoMessage()

func (*ForkConversationResponse) ProtoReflect

func (x *ForkConversationResponse) ProtoReflect() protoreflect.Message

func (*ForkConversationResponse) Reset

func (x *ForkConversationResponse) Reset()

func (*ForkConversationResponse) String

func (x *ForkConversationResponse) String() string

type FunctionCallContent

type FunctionCallContent struct {
	Name      string           `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	Arguments *structpb.Struct `protobuf:"bytes,4,opt,name=arguments,proto3" json:"arguments,omitempty"`
	// contains filtered or unexported fields
}

func (*FunctionCallContent) Descriptor deprecated

func (*FunctionCallContent) Descriptor() ([]byte, []int)

Deprecated: Use FunctionCallContent.ProtoReflect.Descriptor instead.

func (*FunctionCallContent) GetArguments

func (x *FunctionCallContent) GetArguments() *structpb.Struct

func (*FunctionCallContent) GetName

func (x *FunctionCallContent) GetName() string

func (*FunctionCallContent) ProtoMessage

func (*FunctionCallContent) ProtoMessage()

func (*FunctionCallContent) ProtoReflect

func (x *FunctionCallContent) ProtoReflect() protoreflect.Message

func (*FunctionCallContent) Reset

func (x *FunctionCallContent) Reset()

func (*FunctionCallContent) String

func (x *FunctionCallContent) String() string

type FunctionResultContent

type FunctionResultContent struct {
	Name string `protobuf:"bytes,8,opt,name=name,proto3" json:"name,omitempty"`
	// Types that are valid to be assigned to Result:
	//
	//	*FunctionResultContent_Response
	Result isFunctionResultContent_Result `protobuf_oneof:"result"`
	// contains filtered or unexported fields
}

func (*FunctionResultContent) Descriptor deprecated

func (*FunctionResultContent) Descriptor() ([]byte, []int)

Deprecated: Use FunctionResultContent.ProtoReflect.Descriptor instead.

func (*FunctionResultContent) GetName

func (x *FunctionResultContent) GetName() string

func (*FunctionResultContent) GetResponse

func (x *FunctionResultContent) GetResponse() *structpb.Struct

func (*FunctionResultContent) GetResult

func (x *FunctionResultContent) GetResult() isFunctionResultContent_Result

func (*FunctionResultContent) ProtoMessage

func (*FunctionResultContent) ProtoMessage()

func (*FunctionResultContent) ProtoReflect

func (x *FunctionResultContent) ProtoReflect() protoreflect.Message

func (*FunctionResultContent) Reset

func (x *FunctionResultContent) Reset()

func (*FunctionResultContent) String

func (x *FunctionResultContent) String() string

type FunctionResultContent_Response

type FunctionResultContent_Response struct {
	Response *structpb.Struct `protobuf:"bytes,3,opt,name=response,proto3,oneof"`
}

type HealthCheckRequest

type HealthCheckRequest struct {
	// contains filtered or unexported fields
}

HealthCheckRequest for agent health checks

func (*HealthCheckRequest) Descriptor deprecated

func (*HealthCheckRequest) Descriptor() ([]byte, []int)

Deprecated: Use HealthCheckRequest.ProtoReflect.Descriptor instead.

func (*HealthCheckRequest) ProtoMessage

func (*HealthCheckRequest) ProtoMessage()

func (*HealthCheckRequest) ProtoReflect

func (x *HealthCheckRequest) ProtoReflect() protoreflect.Message

func (*HealthCheckRequest) Reset

func (x *HealthCheckRequest) Reset()

func (*HealthCheckRequest) String

func (x *HealthCheckRequest) String() string

type HealthCheckResponse

type HealthCheckResponse struct {
	Healthy bool   `protobuf:"varint,1,opt,name=healthy,proto3" json:"healthy,omitempty"`
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

HealthCheckResponse contains agent health status

func (*HealthCheckResponse) Descriptor deprecated

func (*HealthCheckResponse) Descriptor() ([]byte, []int)

Deprecated: Use HealthCheckResponse.ProtoReflect.Descriptor instead.

func (*HealthCheckResponse) GetHealthy

func (x *HealthCheckResponse) GetHealthy() bool

func (*HealthCheckResponse) GetMessage

func (x *HealthCheckResponse) GetMessage() string

func (*HealthCheckResponse) ProtoMessage

func (*HealthCheckResponse) ProtoMessage()

func (*HealthCheckResponse) ProtoReflect

func (x *HealthCheckResponse) ProtoReflect() protoreflect.Message

func (*HealthCheckResponse) Reset

func (x *HealthCheckResponse) Reset()

func (*HealthCheckResponse) String

func (x *HealthCheckResponse) String() string

type ImageContent

type ImageContent struct {
	MimeType ImageContent_MimeType `protobuf:"varint,1,opt,name=mime_type,json=mimeType,proto3,enum=ax.ImageContent_MimeType" json:"mime_type,omitempty"`
	// Types that are valid to be assigned to DataOrUri:
	//
	//	*ImageContent_Data
	//	*ImageContent_Uri
	DataOrUri  isImageContent_DataOrUri `protobuf_oneof:"data_or_uri"`
	Resolution MediaResolution          `protobuf:"varint,5,opt,name=resolution,proto3,enum=ax.MediaResolution" json:"resolution,omitempty"`
	// contains filtered or unexported fields
}

An image content block.

func (*ImageContent) Descriptor deprecated

func (*ImageContent) Descriptor() ([]byte, []int)

Deprecated: Use ImageContent.ProtoReflect.Descriptor instead.

func (*ImageContent) GetData

func (x *ImageContent) GetData() []byte

func (*ImageContent) GetDataOrUri

func (x *ImageContent) GetDataOrUri() isImageContent_DataOrUri

func (*ImageContent) GetMimeType

func (x *ImageContent) GetMimeType() ImageContent_MimeType

func (*ImageContent) GetResolution

func (x *ImageContent) GetResolution() MediaResolution

func (*ImageContent) GetUri

func (x *ImageContent) GetUri() string

func (*ImageContent) ProtoMessage

func (*ImageContent) ProtoMessage()

func (*ImageContent) ProtoReflect

func (x *ImageContent) ProtoReflect() protoreflect.Message

func (*ImageContent) Reset

func (x *ImageContent) Reset()

func (*ImageContent) String

func (x *ImageContent) String() string

type ImageContent_Data

type ImageContent_Data struct {
	Data []byte `protobuf:"bytes,2,opt,name=data,proto3,oneof"`
}

type ImageContent_MimeType

type ImageContent_MimeType int32
const (
	ImageContent_TYPE_UNSPECIFIED ImageContent_MimeType = 0
	ImageContent_TYPE_PNG         ImageContent_MimeType = 1 // image/png
	ImageContent_TYPE_JPEG        ImageContent_MimeType = 2 // image/jpeg
	ImageContent_TYPE_WEBP        ImageContent_MimeType = 3 // image/webp
	ImageContent_TYPE_HEIC        ImageContent_MimeType = 4 // image/heic
	ImageContent_TYPE_HEIF        ImageContent_MimeType = 5 // image/heif
	ImageContent_TYPE_GIF         ImageContent_MimeType = 7 // image/gif
	ImageContent_TYPE_BMP         ImageContent_MimeType = 8 // image/bmp
	ImageContent_TYPE_TIFF        ImageContent_MimeType = 9 // image/tiff
)

func (ImageContent_MimeType) Descriptor

func (ImageContent_MimeType) Enum

func (ImageContent_MimeType) EnumDescriptor deprecated

func (ImageContent_MimeType) EnumDescriptor() ([]byte, []int)

Deprecated: Use ImageContent_MimeType.Descriptor instead.

func (ImageContent_MimeType) Number

func (ImageContent_MimeType) String

func (x ImageContent_MimeType) String() string

func (ImageContent_MimeType) Type

type ImageContent_Uri

type ImageContent_Uri struct {
	Uri string `protobuf:"bytes,6,opt,name=uri,proto3,oneof"`
}

type MediaResolution

type MediaResolution int32

Resolution for input media (images/video).

const (
	MediaResolution_MEDIA_RESOLUTION_UNSPECIFIED MediaResolution = 0
	MediaResolution_LOW                          MediaResolution = 1
	MediaResolution_MEDIUM                       MediaResolution = 2
	MediaResolution_HIGH                         MediaResolution = 3
	MediaResolution_ULTRA_HIGH                   MediaResolution = 4
)

func (MediaResolution) Descriptor

func (MediaResolution) Enum

func (x MediaResolution) Enum() *MediaResolution

func (MediaResolution) EnumDescriptor deprecated

func (MediaResolution) EnumDescriptor() ([]byte, []int)

Deprecated: Use MediaResolution.Descriptor instead.

func (MediaResolution) Number

func (MediaResolution) String

func (x MediaResolution) String() string

func (MediaResolution) Type

type Message

type Message struct {
	Role    string   `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"`       // user, assistant, or model
	Content *Content `protobuf:"bytes,2,opt,name=content,proto3" json:"content,omitempty"` // content of the message
	// If true, the message is stored only in the execution log
	// (for resumption) but not in the conversation history,
	// and not emitted to the client or any agent.
	InternalOnly bool `protobuf:"varint,3,opt,name=internal_only,json=internalOnly,proto3" json:"internal_only,omitempty"`
	// contains filtered or unexported fields
}

Message is a message in the history.

func (*Message) Descriptor deprecated

func (*Message) Descriptor() ([]byte, []int)

Deprecated: Use Message.ProtoReflect.Descriptor instead.

func (*Message) GetContent

func (x *Message) GetContent() *Content

func (*Message) GetInternalOnly

func (x *Message) GetInternalOnly() bool

func (*Message) GetRole

func (x *Message) GetRole() string

func (*Message) ProtoMessage

func (*Message) ProtoMessage()

func (*Message) ProtoReflect

func (x *Message) ProtoReflect() protoreflect.Message

func (*Message) Reset

func (x *Message) Reset()

func (*Message) String

func (x *Message) String() string

type State

type State int32

State represents the state of an execution

const (
	State_STATE_UNSPECIFIED State = 0 // Unspecified state
	State_STATE_PENDING     State = 1
	State_STATE_FAILED      State = 2
	State_STATE_COMPLETED   State = 3
)

func (State) Descriptor

func (State) Descriptor() protoreflect.EnumDescriptor

func (State) Enum

func (x State) Enum() *State

func (State) EnumDescriptor deprecated

func (State) EnumDescriptor() ([]byte, []int)

Deprecated: Use State.Descriptor instead.

func (State) Number

func (x State) Number() protoreflect.EnumNumber

func (State) String

func (x State) String() string

func (State) Type

func (State) Type() protoreflect.EnumType

type TextContent

type TextContent struct {
	Text string `protobuf:"bytes,3,opt,name=text,proto3" json:"text,omitempty"`
	// contains filtered or unexported fields
}

TextContent represents a text content.

func (*TextContent) Descriptor deprecated

func (*TextContent) Descriptor() ([]byte, []int)

Deprecated: Use TextContent.ProtoReflect.Descriptor instead.

func (*TextContent) GetText

func (x *TextContent) GetText() string

func (*TextContent) ProtoMessage

func (*TextContent) ProtoMessage()

func (*TextContent) ProtoReflect

func (x *TextContent) ProtoReflect() protoreflect.Message

func (*TextContent) Reset

func (x *TextContent) Reset()

func (*TextContent) String

func (x *TextContent) String() string

type ThoughtContent

type ThoughtContent struct {
	Signature []byte                   `protobuf:"bytes,7,opt,name=signature,proto3" json:"signature,omitempty"`
	Summary   []*ThoughtSummaryContent `protobuf:"bytes,9,rep,name=summary,proto3" json:"summary,omitempty"`
	// contains filtered or unexported fields
}

func (*ThoughtContent) Descriptor deprecated

func (*ThoughtContent) Descriptor() ([]byte, []int)

Deprecated: Use ThoughtContent.ProtoReflect.Descriptor instead.

func (*ThoughtContent) GetSignature

func (x *ThoughtContent) GetSignature() []byte

func (*ThoughtContent) GetSummary

func (x *ThoughtContent) GetSummary() []*ThoughtSummaryContent

func (*ThoughtContent) ProtoMessage

func (*ThoughtContent) ProtoMessage()

func (*ThoughtContent) ProtoReflect

func (x *ThoughtContent) ProtoReflect() protoreflect.Message

func (*ThoughtContent) Reset

func (x *ThoughtContent) Reset()

func (*ThoughtContent) String

func (x *ThoughtContent) String() string

type ThoughtSummaryContent

type ThoughtSummaryContent struct {

	// Types that are valid to be assigned to Type:
	//
	//	*ThoughtSummaryContent_Text
	Type isThoughtSummaryContent_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

func (*ThoughtSummaryContent) Descriptor deprecated

func (*ThoughtSummaryContent) Descriptor() ([]byte, []int)

Deprecated: Use ThoughtSummaryContent.ProtoReflect.Descriptor instead.

func (*ThoughtSummaryContent) GetText

func (x *ThoughtSummaryContent) GetText() *TextContent

func (*ThoughtSummaryContent) GetType

func (x *ThoughtSummaryContent) GetType() isThoughtSummaryContent_Type

func (*ThoughtSummaryContent) ProtoMessage

func (*ThoughtSummaryContent) ProtoMessage()

func (*ThoughtSummaryContent) ProtoReflect

func (x *ThoughtSummaryContent) ProtoReflect() protoreflect.Message

func (*ThoughtSummaryContent) Reset

func (x *ThoughtSummaryContent) Reset()

func (*ThoughtSummaryContent) String

func (x *ThoughtSummaryContent) String() string

type ThoughtSummaryContent_Text

type ThoughtSummaryContent_Text struct {
	Text *TextContent `protobuf:"bytes,1,opt,name=text,proto3,oneof"`
}

type ToolCallContent

type ToolCallContent struct {
	Id        string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`               // A unique ID for this specific tool call.
	Signature []byte `protobuf:"bytes,9,opt,name=signature,proto3" json:"signature,omitempty"` // A signature hash for backend validation.
	// Types that are valid to be assigned to Type:
	//
	//	*ToolCallContent_FunctionCall
	Type isToolCallContent_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

func (*ToolCallContent) Descriptor deprecated

func (*ToolCallContent) Descriptor() ([]byte, []int)

Deprecated: Use ToolCallContent.ProtoReflect.Descriptor instead.

func (*ToolCallContent) GetFunctionCall

func (x *ToolCallContent) GetFunctionCall() *FunctionCallContent

func (*ToolCallContent) GetId

func (x *ToolCallContent) GetId() string

func (*ToolCallContent) GetSignature

func (x *ToolCallContent) GetSignature() []byte

func (*ToolCallContent) GetType

func (x *ToolCallContent) GetType() isToolCallContent_Type

func (*ToolCallContent) ProtoMessage

func (*ToolCallContent) ProtoMessage()

func (*ToolCallContent) ProtoReflect

func (x *ToolCallContent) ProtoReflect() protoreflect.Message

func (*ToolCallContent) Reset

func (x *ToolCallContent) Reset()

func (*ToolCallContent) String

func (x *ToolCallContent) String() string

type ToolCallContent_FunctionCall

type ToolCallContent_FunctionCall struct {
	FunctionCall *FunctionCallContent `protobuf:"bytes,2,opt,name=function_call,json=functionCall,proto3,oneof"`
}

type ToolResultContent

type ToolResultContent struct {
	CallId    string `protobuf:"bytes,8,opt,name=call_id,json=callId,proto3" json:"call_id,omitempty"` // ID to match the ID from the function call block.
	Signature []byte `protobuf:"bytes,9,opt,name=signature,proto3" json:"signature,omitempty"`         // A signature hash for backend validation.
	// Types that are valid to be assigned to Type:
	//
	//	*ToolResultContent_FunctionResult
	Type isToolResultContent_Type `protobuf_oneof:"type"`
	// contains filtered or unexported fields
}

func (*ToolResultContent) Descriptor deprecated

func (*ToolResultContent) Descriptor() ([]byte, []int)

Deprecated: Use ToolResultContent.ProtoReflect.Descriptor instead.

func (*ToolResultContent) GetCallId

func (x *ToolResultContent) GetCallId() string

func (*ToolResultContent) GetFunctionResult

func (x *ToolResultContent) GetFunctionResult() *FunctionResultContent

func (*ToolResultContent) GetSignature

func (x *ToolResultContent) GetSignature() []byte

func (*ToolResultContent) GetType

func (x *ToolResultContent) GetType() isToolResultContent_Type

func (*ToolResultContent) ProtoMessage

func (*ToolResultContent) ProtoMessage()

func (*ToolResultContent) ProtoReflect

func (x *ToolResultContent) ProtoReflect() protoreflect.Message

func (*ToolResultContent) Reset

func (x *ToolResultContent) Reset()

func (*ToolResultContent) String

func (x *ToolResultContent) String() string

type ToolResultContent_FunctionResult

type ToolResultContent_FunctionResult struct {
	FunctionResult *FunctionResultContent `protobuf:"bytes,2,opt,name=function_result,json=functionResult,proto3,oneof"`
}

type UnimplementedAgentServiceServer

type UnimplementedAgentServiceServer struct{}

UnimplementedAgentServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAgentServiceServer) Connect

func (UnimplementedAgentServiceServer) HealthCheck

type UnimplementedControllerServiceServer

type UnimplementedControllerServiceServer struct{}

UnimplementedControllerServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedControllerServiceServer) Exec

type UnimplementedConversationServiceServer

type UnimplementedConversationServiceServer struct{}

UnimplementedConversationServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedConversationServiceServer) DeleteConversation

func (UnimplementedConversationServiceServer) ForkConversation

type UnsafeAgentServiceServer

type UnsafeAgentServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAgentServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AgentServiceServer will result in compilation errors.

type UnsafeControllerServiceServer

type UnsafeControllerServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeControllerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ControllerServiceServer will result in compilation errors.

type UnsafeConversationServiceServer

type UnsafeConversationServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeConversationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConversationServiceServer will result in compilation errors.

type VideoContent

type VideoContent struct {
	MimeType VideoContent_MimeType `protobuf:"varint,1,opt,name=mime_type,json=mimeType,proto3,enum=ax.VideoContent_MimeType" json:"mime_type,omitempty"`
	// Types that are valid to be assigned to DataOrUri:
	//
	//	*VideoContent_Data
	//	*VideoContent_Uri
	DataOrUri  isVideoContent_DataOrUri `protobuf_oneof:"data_or_uri"`
	Resolution MediaResolution          `protobuf:"varint,5,opt,name=resolution,proto3,enum=ax.MediaResolution" json:"resolution,omitempty"`
	// contains filtered or unexported fields
}

A video content block.

func (*VideoContent) Descriptor deprecated

func (*VideoContent) Descriptor() ([]byte, []int)

Deprecated: Use VideoContent.ProtoReflect.Descriptor instead.

func (*VideoContent) GetData

func (x *VideoContent) GetData() []byte

func (*VideoContent) GetDataOrUri

func (x *VideoContent) GetDataOrUri() isVideoContent_DataOrUri

func (*VideoContent) GetMimeType

func (x *VideoContent) GetMimeType() VideoContent_MimeType

func (*VideoContent) GetResolution

func (x *VideoContent) GetResolution() MediaResolution

func (*VideoContent) GetUri

func (x *VideoContent) GetUri() string

func (*VideoContent) ProtoMessage

func (*VideoContent) ProtoMessage()

func (*VideoContent) ProtoReflect

func (x *VideoContent) ProtoReflect() protoreflect.Message

func (*VideoContent) Reset

func (x *VideoContent) Reset()

func (*VideoContent) String

func (x *VideoContent) String() string

type VideoContent_Data

type VideoContent_Data struct {
	Data []byte `protobuf:"bytes,2,opt,name=data,proto3,oneof"`
}

type VideoContent_MimeType

type VideoContent_MimeType int32
const (
	VideoContent_TYPE_UNSPECIFIED VideoContent_MimeType = 0
	VideoContent_TYPE_MP4         VideoContent_MimeType = 1 // video/mp4
	VideoContent_TYPE_MPEG        VideoContent_MimeType = 2 // video/mpeg
	VideoContent_TYPE_MPG         VideoContent_MimeType = 3 // video/mpg
	VideoContent_TYPE_MOV         VideoContent_MimeType = 4 // video/mov
	VideoContent_TYPE_AVI         VideoContent_MimeType = 5 // video/avi
	VideoContent_TYPE_X_FLV       VideoContent_MimeType = 6 // video/x-flv
	VideoContent_TYPE_WEBM        VideoContent_MimeType = 7 // video/webm
	VideoContent_TYPE_WMV         VideoContent_MimeType = 8 // video/wmv
	VideoContent_TYPE_3GPP        VideoContent_MimeType = 9 // video/3gpp
)

func (VideoContent_MimeType) Descriptor

func (VideoContent_MimeType) Enum

func (VideoContent_MimeType) EnumDescriptor deprecated

func (VideoContent_MimeType) EnumDescriptor() ([]byte, []int)

Deprecated: Use VideoContent_MimeType.Descriptor instead.

func (VideoContent_MimeType) Number

func (VideoContent_MimeType) String

func (x VideoContent_MimeType) String() string

func (VideoContent_MimeType) Type

type VideoContent_Uri

type VideoContent_Uri struct {
	Uri string `protobuf:"bytes,6,opt,name=uri,proto3,oneof"`
}

Jump to